# Topsis-Rishika-101953022
It takes dataset, weights and impacts associated to the columns of dataset and output file to perform topsis on input dataset.

## Installation
```pip install Topsis-Rishika-101953022```

## Usage
Step 1: Open the command prompt
Step 2: type 
> python <filename> <dataset> <weights> <impacts> <outputfilename>

